@@ -50,7 +50,7 @@ class EnviarPedido(Enviar):
             paymentrequest_0_paymentaction='SALE',
             paymentrequest_0_notifyurl=notification_url,
             paymentrequest_0_amt=self.formatador.formata_decimal(self.pedido.valor_total),
-            paymentrequest_0_shippingamt=self.formatador.formata_decimal(self.pedido.valor_envio),
+            paymentrequest_0_shippingamt=self.formatador.formata_decimal(self.valor_envio),
             paymentrequest_0_currencycode="BRL",
             paymentrequest_0_itemamt=self.formatador.formata_decimal(self.pedido.valor_subtotal),
             paymentrequest_0_invnum=self.pedido.numero,
